@@ -1,7 +1,7 @@
 rpart.anova <- function(y, offset, parms, wt)
 {
     if (!is.null(offset)) y <- y-offset
-    list(y=y, parms=0L, numresp=1L, numy=1L,
+    list(y=y, parms=NULL, numresp=1L, numy=1L,
 	 summary= function(yval, dev, wt, ylevel, digits ) {
 	     paste("  mean=", formatg(yval, digits),
 		   ", MSE=" , formatg(dev/wt, digits),
