@@ -2,7 +2,7 @@
 rpartco <- function(tree, parms)
 {
     if (missing(parms)) {
-        pn <- paste0("device", dev.cur())
+        pn <- paste("device", dev.cur(), sep = "")
         if (!exists(pn, envir = rpart_env, inherits = FALSE))
             stop("no information available on parameters from previous call to plot()")
         parms <- get(pn, envir = rpart_env, inherits = FALSE)
