@@ -9,9 +9,6 @@
 **  error        - Function that returns the prediction error.
 **  num_y        - Number of columns needed to represent y (usually 1)
 */
-#ifndef FLOAT
-#define FLOAT float   /*see comments in rpart.h */
-#endif
 
 extern int anovainit( int n,	    double*y[],  int maxcat, char **error, 
 		      double *parm, int *size,   int who,    double *wt);
@@ -31,17 +28,17 @@ extern void ginidev   (int n,     double *y[], double *value, double *risk,
 extern void usersplit_eval(int n,     double *y[], double *value, double *risk,
                            double *wt);
 
-extern void anova(    int n,    double *y[],     FLOAT *x,     int nclass, 
-                      int edge, double *improve, FLOAT *split, int *csplit, 
+extern void anova(    int n,    double *y[],     double *x,     int nclass, 
+                      int edge, double *improve, double *split, int *csplit, 
                       double myrisk,             double *wt);
-extern void poisson(  int n,    double *y[],     FLOAT *x,     int nclass, 
-                      int edge, double *improve, FLOAT *split, int *csplit, 
+extern void poisson(  int n,    double *y[],     double *x,     int nclass, 
+                      int edge, double *improve, double *split, int *csplit, 
                       double myrisk,             double *wt);
-extern void gini(     int n,    double *y[],     FLOAT *x,     int nclass, 
-                      int edge, double *improve, FLOAT *split, int *csplit, 
+extern void gini(     int n,    double *y[],     double *x,     int nclass, 
+                      int edge, double *improve, double *split, int *csplit, 
                       double myrisk,             double *wt);
-extern void usersplit(int n,    double *y[],     FLOAT *x,     int nclass, 
-                      int edge, double *improve, FLOAT *split, int *csplit, 
+extern void usersplit(int n,    double *y[],     double *x,     int nclass, 
+                      int edge, double *improve, double *split, int *csplit, 
                       double myrisk,             double *wt);
 
 extern double anovapred  (double *y, double *yhat);
@@ -50,15 +47,15 @@ extern double poissonpred(double *y, double *yhat);
 extern double usersplit_pred(double *y, double *yhat);
     
 static struct {
-	int  (*init_split)();
-	void (*choose_split)();
-	void (*eval)();
-	double (*error)();
-	  } func_table [] =
-		 {{anovainit,   anova,   anovass,    anovapred},
-		  {poissoninit, poisson, poissondev, poissonpred},
-		  {giniinit, gini, ginidev, ginipred},
-		  {usersplit_init, usersplit, usersplit_eval, usersplit_pred}
-		 };
+    int  (*init_split)();
+    void (*choose_split)();
+    void (*eval)();
+    double (*error)();
+} func_table [] = {
+    {anovainit,   anova,   anovass,    anovapred},
+    {poissoninit, poisson, poissondev, poissonpred},
+    {giniinit, gini, ginidev, ginipred},
+    {usersplit_init, usersplit, usersplit_eval, usersplit_pred}
+};
 
 #define NUM_METHODS 4  /*size of the above structure */
