@@ -8,21 +8,19 @@
 **      keep    1=keep this one, 0=don't
 */
 #include "rpart.h"
-#include "rpartproto.h"
+#include <Rinternals.h>
 
-void rpartexp2(Sint *n2, double *y, double *eps, int *keep) {
-    int n;
+static void Rpartexp2(int n, double *y, double eps, int *keep)
+{
     double delta;
     int i, j;
     double lasty;
-	    
-    n = *n2;
-    
+
     /* let delta = eps * interquartile range */
 
     i = n/4;
     j = (3*n)/4;
-    delta = *eps * (y[j] - y[i]);
+    delta = eps * (y[j] - y[i]);
 
 
     /*
@@ -36,8 +34,15 @@ void rpartexp2(Sint *n2, double *y, double *eps, int *keep) {
 	else {
 	    keep[i] =1;
 	    lasty = y[i];
-	    }
 	}
     }
+}
 
-
+SEXP rpartexp2(SEXP dtimes, SEXP eps)
+{
+    int n = LENGTH(dtimes);
+    SEXP keep = PROTECT(allocVector(INTSXP, n));
+    Rpartexp2(n, REAL(dtimes), asReal(eps), INTEGER(keep));
+    UNPROTECT(1);
+    return keep;
+}
